@@ -918,6 +918,7 @@ mod tests {
     t!(svg1_1_text_align_02_b_svg,                                  "svg1.1/text-align-02-b.svg");
     t!(svg1_1_text_align_03_b_svg,                                  "svg1.1/text-align-03-b.svg");
     t!(svg1_1_text_fonts_02_t_svg,                                  "svg1.1/text-fonts-02-t.svg");
+    t!(svg1_1_text_dominant_baseline_01_svg,                        "svg1.1/text-dominant-baseline-01.svg");
     t!(svg1_1_text_text_03_b_svg,                                   "svg1.1/text-text-03-b.svg");
     t!(svg1_1_text_text_08_b_svg,                                   "svg1.1/text-text-08-b.svg");
     t!(svg1_1_text_text_10_t_svg,                                   "svg1.1/text-text-10-t.svg");
@@ -1190,6 +1191,12 @@ test_svg_reference!(
     "tests/fixtures/reftests/xinclude-data-url-ref.svg"
 );
 
+test_svg_reference!(
+    xinclude_non_utf8,
+    "tests/fixtures/reftests/xinclude-non-utf8.svg",
+    "tests/fixtures/reftests/xinclude-non-utf8-ref.svg"
+);
+
 test_svg_reference!(
     markers_arc_segments,
     "tests/fixtures/reftests/markers-arc-segments.svg",
@@ -1201,3 +1208,15 @@ test_svg_reference!(
     "tests/fixtures/reftests/bugs-reftests/bug1121-feimage-embedded-svg.svg",
     "tests/fixtures/reftests/bugs-reftests/bug1121-feimage-embedded-svg-ref.svg"
 );
+
+test_svg_reference!(
+    conv_kernel_matrix_length,
+    "tests/fixtures/reftests/filter-conv-kernel-matrix-length.svg",
+    "tests/fixtures/reftests/filter-conv-kernel-matrix-length-ref.svg"
+);
+
+test_svg_reference!(
+    conv_target,
+    "tests/fixtures/reftests/filter-conv-target.svg",
+    "tests/fixtures/reftests/filter-conv-target-ref.svg"
+);
